<?php
/**
 * =======================================================================================
 *                           GemFramework (c) GemPixel                                     
 * ---------------------------------------------------------------------------------------
 *  This software is packaged with an exclusive framework as such distribution
 *  or modification of this framework is not allowed before prior consent from
 *  GemPixel. If you find that this framework is packaged in a software not distributed 
 *  by GemPixel or authorized parties, you must not use this software and contact gempixel
 *  at https://gempixel.com/contact to inform them of this misuse.
 * =======================================================================================
 *
 * @package GemPixel\Premium-URL-Shortener
 * @author GemPixel (https://gempixel.com) 
 * @license https://gempixel.com/licenses
 * @link https://gempixel.com  
 */
use Core\Plugin;
use Core\View;
use Core\DB;

Gem::post('/admin/themes/settings/update', 'themeSettings@update')->name('admin.themes.update');

Plugin::register('admin.theme.getoptions', [themeSettings::class, 'settings']);
Plugin::register('admin.theme.activate', [themeSettings::class, 'activate']);
Plugin::register('admin.theme.update', [themeSettings::class, 'updated']);

Plugin::register('homemenu', [themeSettings::class, 'menu']);

themeSettings::int();

/**
 * Testimonials
 *
 * @author GemPixel <https://gempixel.com> 
 * @version 1.0
 * @return void
 */
function testimonialsItems(){

    if(!config('testimonials')) return;

    echo "<div class='owl-carousel testimonials'>";
    foreach (config('testimonials') as $item) {
        echo  "<div class='testimonial-item'>";
            echo  "<p>{$item->testimonial}</p>";
            echo  "<div class='d-flex'>";
                if(isset($item->email) && !empty($item->email)) {
                    echo  "<div class='media-left pull-left'><img src='https://www.gravatar.com/avatar/".md5(trim($item->email))."?s=64&d=identicon' class='media-object'></div>";
                }
                echo  "<div class='media-body'><div class='media-heading'>{$item->name} <span>".(isset($item->job) ? $item->job : "")."</span></div></div>";
            echo  "</div>";
        echo  "</div>";
    }
    echo  "</div>";
}
/**
 * Logo
 *
 * @author GemPixel <https://gempixel.com> 
 * @version 1.0
 * @return void
 */
function logo(){
    
    if(isset(config('theme_config')->logo) && !empty(config('theme_config')->logo)) {
        $link = $logo;
    }else{
        $link = uploads(config('logo'));
    }
    echo '<img src="'.$link.'" alt="'.config("title").'" style="max-height: 40px">';
}

/**
 * getAddress
 * @author KBRmedia <https://gempixel.com>
 * @version 1.0
 * @return  [type] [description]
 */
function getAddress(){
    
    $address = config('theme_config')->address;

    if(!$address) return false;

    if($address){				
        echo '<h3 class="address">'.e("Our office").'</h3>';
        if(!empty($address->street)){
            echo "<p><i class='fa fa-map text-dark'></i> {$address->street}</p>";						
        }
        if(!empty($address->city) && !empty($address->state)){
            echo "<p class='pad'>{$address->city}, {$address->state}</p>";
        }					
        if(!empty($address->country)){
            echo "<p class='pad'>{$address->country}</p>";								
        }				
        if(!empty($address->phone))		{
            echo "<p class='phone'><i class='fa fa-phone text-dark'></i> {$address->phone}</p>";								
        }
    }
    return false;
}

/**
 * [saasTopCountry description]
 * @author KBRmedia <https://gempixel.com>
 * @version 1.0
 * @return  [type] [description]
 */
function saasTopCountry($text){
    
    $user = user();
    
    $data = DB::stats()
                ->select('country', 'country')
                ->selectExpr('COUNT(country)', 'count')
                ->where('urluserid', $user->id)
                ->groupBy('country')
                ->orderByDesc('count')
                ->first();

    if(isset($data->country) && !empty($data->country)){
        return $text." <img src=\"".\Helpers\App::flag($data->country)."\" width=\"16\" class=\"mx-1\"> ".ucwords($data->country);
    }else{
        return "N/A";
    }
}
/**
 * [saasTopReferrer description]
 * @author KBRmedia <https://gempixel.com>
 * @version 1.0
 * @return  [type] [description]
 */
function saasTopReferrer($text){
    
    $user = user();

    $data = DB::stats()
            ->select('domain', 'domain')
            ->selectExpr('COUNT(domain)', 'count')
            ->where('urluserid', $user->id)
            ->groupBy('domain')
            ->orderByDesc('count')
            ->first();
            
    if(isset($data->domain) && !empty($data->domain)){
        return $text." ".$data->domain;
    }else{
        return $text." ".e("Direct, email and other");
    }
}
/**
 * [saasDevice description]
 * @author KBRmedia <https://gempixel.com>
 * @version 1.0
 * @param   [type] $text [description]
 * @return  [type]       [description]
 */
function saasDevice($text){
    $user = user();

    $data = DB::stats()
            ->select('os', 'os')
            ->selectExpr('COUNT(os)', 'count')
            ->where('urluserid', $user->id)
            ->groupBy('os')
            ->orderByDesc('count')
            ->first();
    	
    if(isset($data->os) && !empty($data->os)){
        return $text." ".ucwords($data->os);
    }else{
        return "N/A";
    }			
}